summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorMatthias P. Braendli <matthias.braendli@mpb.li>2016-09-09 15:00:10 +0200
committerMatthias P. Braendli <matthias.braendli@mpb.li>2016-09-10 20:16:09 +0200
commit0c0840f432c081dff796999b8254866ff0cee6c5 (patch)
tree35a95a4d39517634762b9e545f777250883c7fe8 /src
parent14c7b800eaa23e9da7c92c7c4df397d0c191f097 (diff)
downloadODR-AudioEnc-0c0840f432c081dff796999b8254866ff0cee6c5.tar.gz
ODR-AudioEnc-0c0840f432c081dff796999b8254866ff0cee6c5.tar.bz2
ODR-AudioEnc-0c0840f432c081dff796999b8254866ff0cee6c5.zip
Link against external fdk, rename to odr-audioencoder
Diffstat (limited to 'src')
-rw-r--r--src/odr-audioencoder.cpp (renamed from src/dabplus-enc.cpp)8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/dabplus-enc.cpp b/src/odr-audioencoder.cpp
index 35a7496..d98df64 100644
--- a/src/dabplus-enc.cpp
+++ b/src/odr-audioencoder.cpp
@@ -32,7 +32,7 @@
* The readme for the whole package is \ref md_README
*
* Interesting starting points for the encoder
* - \ref dabplus-enc.cpp Main encoder file
* - \ref VLCInput.h VLC Input
* - \ref AlsaInput.h Alsa Input
* - \ref JackInput.h JACK Input
@@ -47,7 +47,7 @@
* - \ref mot-encoder.cpp
*
*
- * \file dabplus-enc.cpp
+ * \file odr-audioencoder.cpp
* \brief The main file for the audio encoder
*/
@@ -81,7 +81,7 @@ extern "C" {
#include <sys/ioctl.h>
#include <fcntl.h>
-#include "libAACenc/include/aacenc_lib.h"
+#include "fdk-aac/aacenc_lib.h"
extern "C" {
#include <fec.h>
@@ -100,7 +100,7 @@ using namespace std;
void usage(const char* name) {
fprintf(stderr,
- "dabplus-enc %s is an audio encoder for both DAB and DAB+.\n"
+ "ODR-AudioEncoder %s is an audio encoder for both DAB and DAB+.\n"
"The DAB+ HE-AACv2 encoder is based on a Thirt-Party Modified\n"
"Version of the Fraunhofer FDK AAC Codec Library for Android,\n"
"and the DAB encoder is using the tooLAME MPEG\n"
@@ -32,7 +32,7 @@
*
* Interesting starting points for the encoder
- * - \ref dabplus-enc.cpp Main encoder file
+ * - \ref odr-audioencoder.cpp Main encoder file
* - \ref VLCInput.h VLC Input
* - \ref AlsaInput.h Alsa Input